import 'package:domain/generated/json/base/json_field.dart';
import 'package:domain/generated/json/labour_request_e_r_entity.g.dart';
import 'dart:convert';
export 'package:domain/generated/json/labour_request_e_r_entity.g.dart';

@JsonSerializable()
class LabourRequestEREntity {
	@JSONField(name: "count_list")
	List<LabourRequestERCountList> countList = [];
	@JSONField(name: "source_list")
	List<LabourRequestERSourceList> sourceList = [];
	String? view;

	LabourRequestEREntity();

	factory LabourRequestEREntity.fromJson(Map<String, dynamic> json) => $LabourRequestEREntityFromJson(json);

	Map<String, dynamic> toJson() => $LabourRequestEREntityToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class LabourRequestERCountList {
	String? date;
	String? week;
	String? num;

	LabourRequestERCountList();

	factory LabourRequestERCountList.fromJson(Map<String, dynamic> json) => $LabourRequestERCountListFromJson(json);

	Map<String, dynamic> toJson() => $LabourRequestERCountListToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class LabourRequestERSourceList {
	@JSONField(name: "agency_id")
	String? agencyId;
	@JSONField(name: "agency_name")
	String? agencyName;
	@JSONField(name: "request_list")
	List<LabourRequestERSourceListRequestList>? requestList = [];

	LabourRequestERSourceList();

	factory LabourRequestERSourceList.fromJson(Map<String, dynamic> json) => $LabourRequestERSourceListFromJson(json);

	Map<String, dynamic> toJson() => $LabourRequestERSourceListToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}

@JsonSerializable()
class LabourRequestERSourceListRequestList {
	String? date;
	String? num;

	LabourRequestERSourceListRequestList();

	factory LabourRequestERSourceListRequestList.fromJson(Map<String, dynamic> json) => $LabourRequestERSourceListRequestListFromJson(json);

	Map<String, dynamic> toJson() => $LabourRequestERSourceListRequestListToJson(this);

	@override
	String toString() {
		return jsonEncode(this);
	}
}